import React from 'react';
import { Icon, Form, Button, Input, Select, Spin, Table, DatePicker, message, Modal, Radio, Upload } from 'antd';
import { cognizanceStateList } from '../../dataDic.js';
import { getCognizanceState, beforeUpload, beforeUploadFile, downloadFile } from '../../tools.js';
import ajax from 'jquery/src/ajax/xhr.js';
import $ from 'jquery/src/ajax';

const ApplyChangeFrom = Form.create()(React.createClass({
    loadData(id) {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/user/techproject/techProjectDetial",
            data: {
                pid: id || this.props.data.pid
            },
            success: function (data) {
                if (data.error.length || !data.data) {
                    message.warning(data.error[0].message);
                    return;
                };
                this.state.data = data.data;
                this.state.moneyType = undefined;
                if (data.data.projectMode == 1) {
                    this.state.projectMode = data.data.projectMode;
                    this.setState({ moneyType: 2 });
                };
                if (data.data.subsidy == 1) {
                    this.state.subsidy = data.data.subsidy;
                    this.setState({ moneyType: 1 });
                };
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getStateData(id) {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/user/techproject/techProjectLog",
            data: {
                pid: id || this.props.data.pid
            },
            success: function (data) {
                if (data.error.length || !data.data) {
                    message.warning(data.error[0].message);
                    return;
                };
                var myDate = new Date();
                this.state.stateTable = [];
                for (let i = 0; i < data.data.length; i++) {
                    this.state.stateTable.push({
                        key: i,
                        state: data.data[i].state,
                        recordTime: myDate.toLocaleDateString(data.data[i].recordTime),
                        principal: data.data[i].principal,
                        comment: data.data[i].comment
                    });
                };
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getInitialState() {
        return {
            loading: false,
            departmentOption: [],
            projectDes: '',
            projectMode: 0,
            subsidy: 0,
            projectModeState: false,
            subsidyState: false,
            stateColumns: [{
                title: '专利状态',
                dataIndex: 'state',
                key: 'state',
                render: (text) => { return getCognizanceState(text) }
            }, {
                title: '处理时间',
                dataIndex: 'recordTime',
                key: 'recordTime'
            }, {
                title: '负责人',
                dataIndex: 'principal',
                key: 'principal',
            }, {
                title: '备注',
                dataIndex: 'comment',
                key: 'comment',
            }],
            stateTable: []
        };
    },
    componentWillMount() {
        this.loadData();
        this.getStateData();
    },
    handleSubmit(e) {
        e.preventDefault();
        this.props.form.validateFields((err, values) => {
            if (!err) {
                this.props.spinState(true);
                let contacts = !isNaN(values.contacts) ? values.contacts : this.state.data.contacts;
                $.ajax({
                    method: "POST",
                    dataType: "json",
                    crossDomain: false,
                    url: globalConfig.context + "/api/user/techproject/updateTechProject",
                    data: {
                        id: this.props.data.pid,
                        contacts: contacts,
                        department: values.department,
                        projectName: values.projectName,
                        projectCatagory: values.projectCatagory,
                        techField: values.techField,
                        projectDes: values.projectDes,
                        projectMode: this.state.projectMode,
                        projectApproval: values.projectApproval,
                        subsidy: this.state.subsidy,
                        approvalUrl: this.state.approvalUrl,
                    }
                }).done(function (data) {
                    if (!data.error.length) {
                        message.success('保存成功！');
                        this.props.closeModal();
                        this.props.form.resetFields();
                        this.props.spinState(false);
                    } else {
                        message.warning(data.error[0].message);
                        this.props.spinState(false);
                    }
                }.bind(this));
            }
        });
    },
    componentWillReceiveProps(nextProps) {
        if (!this.props.visible && nextProps.visible) {
            this.loadData(nextProps.data.pid);
            this.getStateData(nextProps.data.pid);
        };
    },
    subsidyCheck(e) {
        if (e.target.value == 1) {
            this.state.subsidy = 1;
            this.state.projectMode = 0;
        } else if (e.target.value == 2) {
            this.state.subsidy = 0;
            this.state.projectMode = 1;
        };
        this.setState({
            moneyType: e.target.value
        });
    },
    render() {
        const FormItem = Form.Item;
        const { getFieldDecorator } = this.props.form;
        const theData = this.state.data;
        const formItemLayout = {
            labelCol: { span: 6 },
            wrapperCol: { span: 12 },
        };
        const _me = this;
        if (this.state.data) {
            return (
                <Form onSubmit={this.handleSubmit} id="highTechApply-form">
                    <div className="clearfix">
                        <div className="half-item">
                            <span className="item-title">公司名称: </span>
                            <span>{theData.unitName}</span>
                        </div>
                        <div className="half-item">
                            <span className="item-title">公司组织机构代码: </span>
                            <span>{theData.orgCode}</span>
                        </div>
                        <div className="half-item">
                            <span className="item-title">公司地址: </span>
                            <span>{theData.province + ' ' + theData.city + ' ' + theData.area}</span>
                        </div>
                        <div className="half-item">
                            <FormItem
                                labelCol={{ span: 4 }}
                                wrapperCol={{ span: 10 }}
                                label="联系人:"
                            >
                                {getFieldDecorator('contacts', {
                                    initialValue: String(theData.contacts)
                                })(
                                    <Select>{this.props.contactsOption}</Select>
                                    )}
                            </FormItem>
                        </div>
                    </div>
                    <div className="clearfix">
                        <FormItem className="third-item"
                            {...formItemLayout}
                            label="科技部门"
                        >
                            {getFieldDecorator('department', {
                                initialValue: this.state.department
                            })(
                                <Input />
                                )}
                        </FormItem>
                    </div>
                    <div className="clearfix">
                        <div className="half-item">
                            <span className="item-title">派单信息: </span>
                            <span>{theData.dispatchInfo}</span>
                        </div>
                    </div>
                    <div className="clearfix">
                        <div className="half-item">
                            <FormItem
                                labelCol={{ span: 4 }}
                                wrapperCol={{ span: 12 }}
                                label="项目名称"
                            >
                                {getFieldDecorator('projectName', {
                                    initialValue: theData.projectName
                                })(
                                    <Input />
                                    )}
                            </FormItem>
                        </div>
                    </div>
                    <div className="clearfix">
                        <div className="half-item">
                            <FormItem
                                labelCol={{ span: 4 }}
                                wrapperCol={{ span: 12 }}
                                label="项目类型"
                            >
                                {getFieldDecorator('projectCatagory', {
                                    initialValue: theData.projectCatagory
                                })(
                                    <Input />
                                    )}
                            </FormItem>
                        </div>
                    </div>
                    <div className="clearfix">
                        <div className="half-item">
                            <FormItem
                                labelCol={{ span: 4 }}
                                wrapperCol={{ span: 12 }}
                                label="技术领域"
                            >
                                {getFieldDecorator('techField', {
                                    initialValue: theData.techField
                                })(
                                    <Input />
                                    )}
                            </FormItem>
                        </div>
                    </div>
                    <div className="clearfix">
                        <span className="item-title">项目简介: </span>
                        {getFieldDecorator('projectDes', {
                            initialValue: theData.projectDes
                        })(
                            <Input type="textarea"
                                placeholder="多行输入"
                                rows={6} />
                            )}
                    </div>
                    <div className="clearfix">
                        <div className="half-item">
                            <span className="item-title">立项/后补助: </span>
                            <Radio.Group value={this.state.moneyType} onChange={this.subsidyCheck}>
                                <Radio value={1}>立项</Radio>
                                <Radio value={2}>后补助</Radio>
                            </Radio.Group>
                        </div>
                        <div className="half-item">
                            <FormItem
                                {...formItemLayout}
                                label={this.state.moneyType !== 2 ? '立项金额' : '后补助金额'}
                            >
                                {getFieldDecorator('projectApproval', {
                                    initialValue: theData.projectApproval
                                })(
                                    <Input style={{ width: 200 }} />
                                    )}
                                <span>万元</span>
                            </FormItem>
                        </div>
                    </div>
                    <div className="hrSituation-roster">
                        <Upload
                            name="avatar"
                            action={globalConfig.context + "/api/user/techproject/upload"}
                            data={{ 'uid': this.props.data.uid }}
                            beforeUpload={beforeUploadFile}
                            showUploadList={false}
                            onChange={(info) => {
                                if (info.file.status !== 'uploading') {
                                    console.log(info.file, info.fileList);
                                }
                                if (info.file.status === 'done') {
                                    if (!info.file.response.error.length) {
                                        message.success(`${info.file.name} 文件上传成功！`);
                                    } else {
                                        message.warning(info.file.response.error[0].message);
                                        return;
                                    };
                                    this.state.approvalUrl = info.file.response.data;
                                } else if (info.file.status === 'error') {
                                    message.error(`${info.file.name} 文件上传失败。`);
                                }
                            }}
                        >
                            <Button><Icon type="upload" /> 项目材料上传 </Button>
                        </Upload>
                        <p style={{ marginTop: '10px' }}>{theData.approvalUrl ? <a onClick={downloadFile.bind(null, theData.approvalUrl, theData.approvalDownloadFileName)}>{theData.approvalDownloadFileName}</a> : <span><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />未上传！</span>}</p>
                    </div>
                    <div className="form-title">状态流转记录: </div>
                    <Table pagination={false} dataSource={this.state.stateTable} columns={this.state.stateColumns} />

                    <FormItem style={{ marginTop: '20px' }}>
                        <Button className="set-submit" type="primary" htmlType="submit">保存</Button>
                        <Button type="ghost" style={{ marginLeft: '20px' }} onClick={this.props.closeModal}>取消</Button>
                    </FormItem>
                </Form >
            );
        } else {
            return (<div></div>)
        };
    },
}));

const ApplyChange = React.createClass({
    getInitialState() {
        return {
            visible: false,
            loading: false
        };
    },
    componentWillReceiveProps(nextProps) {
        this.state.visible = nextProps.showDesc
    },
    showModal() {
        this.setState({
            visible: true,
        });
    },
    handleOk() {
        this.setState({
            visible: false,
        });
        this.props.closeDesc(false);
    },
    handleCancel(e) {
        this.setState({
            visible: false,
        });
        this.props.closeDesc(false);
    },
    spinChange(e) {
        this.setState({
            loading: e
        });
    },
    render() {
        return (
            <div className="patent-addNew">
                <Spin spinning={this.state.loading} className='spin-box'>
                    <Modal title="编辑科技项目" visible={this.state.visible}
                        onOk={this.handleOk} onCancel={this.handleCancel}
                        width='1000px'
                        footer=''
                    >
                        <ApplyChangeFrom
                            visible={this.state.visible}
                            data={this.props.data}
                            contactsOption={this.props.contactsOption}
                            spinState={this.spinChange}
                            closeModal={this.handleCancel} />
                    </Modal>
                </Spin>
            </div>
        );
    }
});

export default ApplyChange;