import React from 'react';
import { Icon, Modal, message, Spin, Steps, Input, Select, Upload, DatePicker, Button, Table } from 'antd';
import './comprehensive.less';
import ajax from 'jquery/src/ajax/xhr.js';
import moment from 'moment';
import $ from 'jquery/src/ajax';
import { patentTypeList, patentFieldList, patentStateList } from '../../../dataDic.js';
import { getBase64, beforeUpload, getPatentState, getTime, newDownloadFile } from '../../../tools.js';

class Avatar extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            imageUrl: ''
        }
    }
    handleChange(info) {
        if (info.file.status !== 'uploading') {
            console.log(info.file, info.fileList);
        }
        if (info.file.status === 'done') {
            if (!info.file.response.error.length) {
                message.success(`${info.file.name} 文件上传成功！`);
            } else {
                message.warning(info.file.response.error[0].message);
                return;
            };
            this.props.urlData(info.file.response.data);
        } else if (info.file.status === 'error') {
            message.error(`${info.file.name} 文件上传失败。`);
        };
    }
    render() {
        return (
            <Upload className="upload-file"
                name="avatar"
                showUploadList={false}
                action={globalConfig.context + "/api/admin/patent/upload"}
                data={{ 'sign': this.props.name, 'uid': this.props.uid }}
                beforeUpload={beforeUpload}
                onChange={this.handleChange.bind(this)}
            >
                <Button><Icon type="upload" /> 点击上传 </Button>
            </Upload>
        );
    }
};

const PatentDesc = React.createClass({
    getInitialState() {
        return {
            visible: false,
            loading: false,
            patentTypeOption: [],
            patentFieldOption: [],
            patentStateOption: [],
            adminOption: [],
            stateTable: [],
            stateColumns: [{
                title: '申请状态',
                dataIndex: 'state',
                key: 'state',
                render: (text) => { return getPatentState(text) }
            }, {
                title: '处理时间',
                dataIndex: 'recordTimeFormattedDate',
                key: 'recordTimeFormattedDate',
            }, {
                title: '负责人',
                dataIndex: 'principal',
                key: 'principal',
            }, {
                title: '操作人',
                dataIndex: 'operator',
                key: 'operator',
            }, {
                title: '备注',
                dataIndex: 'comment',
                key: 'comment',
            }]
        };
    },
    loadData() {
        this.setState({
            loading: true
        });
        $.when($.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/patent/detail?pid=" + this.state.xid,
        }), $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/patent/logs?pid=" + this.state.xid,
        }), $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/patent/getPrincipal"
        }), $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/patent/patentStatus"
        })).done((data1, data2, data3, data4) => {
            let _me = this;
            if (data1[0].error.length || !data1[0].data) {
                message.warning(data1[0].error[0].message);
                return;
            };
            this.state.data = data1[0].data;
            this.state.patentDes = data1[0].data.patentDes;
            this.state.patentName = data1[0].data.patentName;
            this.state.patentNumber = data1[0].data.patentNumber;
            this.state.patentCatagory = data1[0].data.patentCatagory;
            this.state.patentState = data1[0].data.patentState;
            this.state.patentField = data1[0].data.patentField;
            this.state.contacts = data1[0].data.contacts;
            if (data2[0].error.length) {
                message.warning(data2[0].error[0].message);
                return;
            };
            _me.state.stateTable = [];
            data2[0].data.map(function (item) {
                _me.state.stateTable.push({
                    comment: item.comment,
                    id: item.id,
                    operator: item.operator,
                    pid: item.pid,
                    principal: item.principal,
                    recordTime: item.recordTime,
                    recordTimeFormattedDate: item.recordTimeFormattedDate,
                    state: item.state,
                });
            });
            if (data3[0].error.length) {
                message.warning(data3[0].error[0].message);
                return;
            };
            for (var item in data3[0].data) {
                _me.state.adminOption.push(
                    <Select.Option value={item} key={item}>{data3[0].data[item]}</Select.Option>
                )
            };
            if (!data4[0].data) {
                if (data4[0].error && data4[0].error.length) {
                    message.warning(data4[0].error[0].message);
                    return;
                };
            };
            _me.state.patentStateOption = [];
            for (var item in data4[0].data) {
                _me.state.patentStateOption.push(
                    <Select.Option value={item} key={item}>{data4[0].data[item]}</Select.Option>
                )
            };
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getContactsList(theUid) {
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/getContacts",
            data: {
                uid: theUid || this.state.uid
            },
            success: function (data) {
                let theOption = [];
                if (data.error.length || !data.data) {
                    return;
                };
                for (let item in data.data) {
                    let theData = data.data[item];
                    theOption.push(
                        <Select.Option value={item} key={theData}>{theData}</Select.Option>
                    );
                };
                this.setState({
                    contactsOption: theOption
                });
            }.bind(this),
        });
    },
    getOption() {
        let _me = this;
        _me.state.patentTypeOption = [];
        _me.state.patentFieldOption = [];
        patentTypeList.map(function (item) {
            _me.state.patentTypeOption.push(
                <Select.Option value={item.value} key={item.key}>{item.key}</Select.Option>
            )
        });
        patentFieldList.map(function (item) {
            _me.state.patentFieldOption.push(
                <Select.Option value={item.value} key={item.key}>{item.key}</Select.Option>
            )
        });
    },
    showModal() {
        this.setState({
            visible: true,
        });
    },
    handleOk() {
        this.setState({
            visible: true,
        });
        $.ajax({
            method: "POST",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/patent/update",
            data: {
                "id": this.state.xid,
                "patentNumber": this.state.patentNumber,
                "patentName": this.state.patentName,
                "patentCatagory": this.state.data.patentCatagory,
                "patentField": this.state.patentField,
                "patentDes": this.state.patentDes,
                "contacts": this.state.contacts,
                "patentWritingUrl": this.state.patentWritingUrl,
                "authorizationNoticeUrl": this.state.authorizationNoticeUrl,
                "patentCertificateUrl": this.state.patentCertificateUrl,
                "pState": this.props.data.patentState,
                "state": this.state.patentStateAdd,
                "recordTimeFormattedDate": this.state.recordTime,
                "principal": this.state.adminName,
                "comment": this.state.comment
            }
        }).done(function (data) {
            if (!data.error.length) {
                message.success('保存成功！');
            } else {
                message.warning(data.error[0].message);
            }
        }.bind(this)).always(function () {
            this.setState({
                visible: false,
            });
            this.props.closeDesc(false, true);
        }.bind(this));
    },
    checkPatentProcess() {
        if (this.state.patentStateAdd || this.state.adminName || this.state.recordTime) {
            if (this.state.patentStateAdd && this.state.adminName && this.state.recordTime)
            { this.handleOk() } else {
                message.warning("请填写完整的状态流转信息！");
                return;
            }
        } else {
            this.handleOk()
        };
    },
    componentWillMount() {
        this.getOption();
    },
    componentWillReceiveProps(nextProps) {
        this.state.patentStateAdd = undefined;
        this.state.adminName = undefined;
        this.state.recordTime = undefined;
        this.state.comment = undefined;
        this.state.adminOption = [];
        if (nextProps.data && !this.state.visible && nextProps.showDesc) {
            this.state.xid = nextProps.data.pid;
            this.loadData();
            this.getContactsList(nextProps.data.uid);
        };
        this.state.visible = nextProps.showDesc;
    },
    handleCancel(e) {
        this.setState({
            visible: false,
        });
        this.props.closeDesc(false);
    },
    getPatentWritingUrl(e) {
        this.state.patentWritingUrl = e;
    },
    getAuthorizationNoticeUrl(e) {
        this.state.authorizationNoticeUrl = e;
    },
    getPatentCertificateUrl(e) {
        this.state.patentCertificateUrl = e;
    },
    render() {
        const Step = Steps.Step;
        const theData = this.state.data;

        if (this.state.data) {
            let companyAddress = theData.locationProvince || theData.locationCity || theData.locationArea ? theData.locationProvince + '/' + theData.locationCity + '/' + theData.locationArea : '';
            return (
                <div className="patent-desc">
                    <Spin spinning={this.state.loading} className='spin-box'>
                        <Modal title="专利详情" visible={this.state.visible}
                            onOk={this.checkPatentProcess} onCancel={this.handleCancel}
                            width='800px'
                            footer={[
                                <Button key="submit" type="primary" size="large" onClick={this.checkPatentProcess}>保存</Button>,
                                <Button key="back" type="ghost" size="large" onClick={this.handleCancel}>取消</Button>,
                            ]}
                            className="patent-desc-content">
                            <div>
                                <p className="widthHalf"><span>公司名称：</span>{theData.unitName}</p>
                                <p className="widthHalf"><span>公司组织机构代码：</span>{theData.orgCode}</p>
                            </div>
                            <div>
                                <p className="widthHalf"><span>公司地址：</span>{companyAddress}</p>
                                <div className="widthHalf">
                                    <span>联系人：</span>
                                    <Select placeholder="选择联系人"
                                        style={{ width: 200 }}
                                        value={this.state.contacts}
                                        onChange={(e) => { this.setState({ contacts: e }); }} >
                                        {this.state.contactsOption}
                                    </Select>
                                </div>
                            </div>
                            <div>
                                <p className="widthHalf"><span>编号：</span>{theData.serialNumber}</p>
                                <p className="widthHalf"><span>申请号/专利号：</span><Input value={this.state.patentNumber} onChange={(e) => { this.setState({ patentNumber: e.target.value }); }} /></p>
                            </div>
                            <div>
                                <p className="widthHalf"><span>专利名称：</span><Input value={this.state.patentName} onChange={(e) => { this.setState({ patentName: e.target.value }); }} /></p>
                                <div className="widthHalf"><span>专利类型：</span>
                                    <Select value={this.state.patentCatagory} style={{ width: 200 }} onChange={(e) => { this.setState({ patentCatagory: e }); }}>{this.state.patentTypeOption}</Select>
                                </div>
                            </div>
                            <div>
                                <p className="widthHalf"><span>专利状态：</span>{getPatentState(theData.patentState)}</p>
                                <div className="widthHalf"><span>专利领域：</span>
                                    <Select value={this.state.patentField} style={{ width: 200 }} onChange={(e) => { this.setState({ patentField: e }); }}>{this.state.patentFieldOption}</Select>
                                </div>
                            </div>
                            <div>
                                <span>专利简介：</span>
                                <Input type="textarea"
                                    placeholder="多行输入"
                                    value={this.state.patentDes}
                                    onChange={(e) => { this.setState({ patentDes: e.target.value }); }}
                                    rows={6} />
                            </div>
                            <div>
                                <p>第一发明人：</p>
                                <p className="widthThird"><span>姓名：</span>{theData.firstInventorName}</p>
                                <p className="widthThird"><span>身份证：</span>{theData.firstInventorIdNumber}</p>
                                <p className="widthThird"><span>国籍：</span>中国</p>
                            </div>
                            <div style={theData.secondInventorName === '' ? { display: 'none' } : {}}>
                                <p>第二发明人：</p>
                                <p className="widthThird"><span>姓名：</span>{theData.secondInventorName}</p>
                                <p className="widthThird"><span>国籍：</span>中国</p>
                            </div>
                            <div style={theData.thirdInventorName === '' ? { display: 'none' } : {}}>
                                <p>第三发明人：</p>
                                <p className="widthThird"><span>姓名：</span>{theData.thirdInventorName}</p>
                                <p className="widthThird"><span>国籍：</span>中国</p>
                            </div>
                            <div className="clearfix">
                                <div>材料管理：
                                    {theData.patentWritingUrl ?
                                        <p className="download-file">
                                            <a onClick={newDownloadFile.bind(null, this.state.xid, "patent_writing", "/api/admin/patent/download")}>专利稿件</a>
                                            {theData.confirmState == '0' ?
                                                <Button onClick={this.confirmButton}>确认稿件</Button> : <span></span>
                                            }
                                        </p> :
                                        <p><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />专利稿件未上传</p>
                                    }
                                    {theData.authorizationNoticeUrl ?
                                        <p className="download-file">
                                            <a onClick={newDownloadFile.bind(null, this.state.xid, "authorization_notice", "/api/admin/patent/download")}>授权通知书</a>
                                        </p> :
                                        <p><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />授权通知书未上传</p>
                                    }
                                    {theData.patentCertificateUrl ?
                                        <p className="download-file">
                                            <a onClick={newDownloadFile.bind(null, this.state.xid, "patent_certificate", "/api/admin/patent/download")}>专利证书</a>
                                        </p> :
                                        <p><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />专利证书未上传</p>
                                    }
                                    {theData.patentProryStatementUrl ?
                                        <p className="download-file">
                                            <a onClick={newDownloadFile.bind(null, this.state.xid, "patent_prory_statement", "/api/admin/patent/download")}>专利代理委托书</a>
                                        </p> :
                                        <p><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />专利代理委托书未上传</p>
                                    }
                                    {theData.lastYearTaxReportUrl ?
                                        <p className="download-file">
                                            <a onClick={newDownloadFile.bind(null, this.state.xid, "last_year_ratepay", "/api/admin/patent/downloadHonor")}>上年度纳税报表</a>
                                        </p> :
                                        <p><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />上年度纳税报表未上传</p>
                                    }
                                </div>
                                <Avatar urlData={this.getPatentWritingUrl} name='patent_writing' uid={theData.uid} />
                                <Avatar urlData={this.getAuthorizationNoticeUrl} name='authorization_notice' uid={theData.uid} />
                                <Avatar urlData={this.getPatentCertificateUrl} name='patent_certificate' uid={theData.uid} />
                            </div>
                            <div className="avatar-text"><span>专利稿件上传</span><span>授权通知书上传</span><span>专利证书上传</span></div>
                            <div className="clearfix">
                                <p>专利状态流转记录：</p>
                                <Table
                                    style={{ margin: '10px 0' }}
                                    pagination={false}
                                    dataSource={this.state.stateTable}
                                    columns={this.state.stateColumns} />
                                <div className="widthThird">
                                    <span>状态流转：</span>
                                    <Select placeholder='请选择状态' value={this.state.patentStateAdd} style={{ width: 150 }} onChange={(e) => { this.setState({ patentStateAdd: e }); }}>{this.state.patentStateOption}</Select>
                                </div>
                                <p className="widthThird">
                                    <span>处理时间：</span>
                                    <DatePicker
                                        value={this.state.recordTime ? moment(this.state.recordTime) : undefined}
                                        format="YYYY-MM-DD HH:mm:ss"
                                        onChange={(data, dataString) => { this.setState({ recordTime: dataString }); }} />
                                </p>
                                <div className="widthThird">
                                    <span>负责人：</span>
                                    <Select placeholder='请填写负责人' value={this.state.adminName} style={{ width: 150 }} onChange={(e) => { this.setState({ adminName: e }); }}>{this.state.adminOption}</Select>
                                </div>
                            </div>
                            <div>
                                <span>备注：</span>
                                <Input value={this.state.comment} placeholder='请填写备注' style={{ width: 400 }} onChange={(e) => { this.setState({ comment: e.target.value }); }} />
                            </div>
                        </Modal>
                    </Spin>
                </div>
            );
        } else {
            return <div></div>
        }
    },
});
export default PatentDesc;